@@ -1,19 +1,9 @@
 import copy
 from typing import TYPE_CHECKING, Any, Dict, Optional
 
-# Type hint imports
-from aiconfig import (
-    ExecuteResult,
-    Output,
-    Prompt,
-    PromptMetadata,
-)
-
-# ModelParser Utils
-from aiconfig import ParameterizedModelParser
-from aiconfig import get_api_key_from_environment
-from aiconfig import resolve_prompt
-from aiconfig import InferenceOptions
+from aiconfig.default_parsers.parameterized_model_parser import ParameterizedModelParser
+from aiconfig.model_parser import InferenceOptions
+from aiconfig.util.config_utils import get_api_key_from_environment
 
 # HuggingFace API imports
 from huggingface_hub import InferenceClient
@@ -22,6 +12,13 @@ from huggingface_hub.inference._text_generation import (
     TextGenerationStreamResponse,
 )
 
+from aiconfig.schema import ExecuteResult, Output, Prompt
+
+from aiconfig.util.params import resolve_prompt
+
+# ModelParser Utils
+# Type hint imports
+
 # Circuluar Dependency Type Hints
 if TYPE_CHECKING:
     from aiconfig.Config import AIConfigRuntime
@@ -94,7 +91,8 @@ def construct_stream_output(
 
         index = 0  # HF Text Generation api doesn't support multiple outputs
         delta = data
-        options.stream_callback(delta, accumulated_message, index)
+        if options and options.stream_callback:
+            options.stream_callback(delta, accumulated_message, index)
 
         output = ExecuteResult(
             **{
@@ -197,12 +195,18 @@ class HuggingFaceTextGenerationParser(ParameterizedModelParser):
         prompt = Prompt(
             name=prompt_name,
             input=prompt_input,
-            metadata=PromptMetadata(model=model_metadata, parameters=parameters, **kwargs),
+            metadata=PromptMetadata(
+                model=model_metadata, parameters=parameters, **kwargs
+            ),
         )
         return [prompt]
 
     async def deserialize(
-        self, prompt: Prompt, aiconfig: "AIConfigRuntime", options, params: Optional[Dict] = {}
+        self,
+        prompt: Prompt,
+        aiconfig: "AIConfigRuntime",
+        options,
+        params: Optional[Dict] = {},
     ) -> Dict:
         """
         Defines how to parse a prompt in the .aiconfig for a particular model
@@ -225,7 +229,9 @@ class HuggingFaceTextGenerationParser(ParameterizedModelParser):
 
         return completion_data
 
-    async def run_inference(self, prompt: Prompt, aiconfig, options, parameters) -> Output:
+    async def run_inference(
+        self, prompt: Prompt, aiconfig, options, parameters
+    ) -> Output:
         """
         Invoked to run a prompt in the .aiconfig. This method should perform
         the actual model inference based on the provided prompt and inference settings.
@@ -240,9 +246,13 @@ class HuggingFaceTextGenerationParser(ParameterizedModelParser):
         completion_data = await self.deserialize(prompt, aiconfig, options, parameters)
 
         # if stream enabled in runtime options and config, then stream. Otherwise don't stream.
-        stream = (options.stream if options else False) and (
-            not "stream" in completion_data or completion_data.get("stream") != False
-        )
+        stream = True  # Default value
+        if options is not None and options.stream is not None:
+            stream = options.stream
+        elif "stream" in completion_data:
+            stream = completion_data["stream"]
+
+        completion_data["stream"] = stream
 
         response = self.client.text_generation(**completion_data)
         response_is_detailed = completion_data.get("details", False)
@@ -262,7 +272,10 @@ class HuggingFaceTextGenerationParser(ParameterizedModelParser):
         return prompt.outputs
 
     def get_output_text(
-        self, prompt: Prompt, aiconfig: "AIConfigRuntime", output: Optional[Output] = None
+        self,
+        prompt: Prompt,
+        aiconfig: "AIConfigRuntime",
+        output: Optional[Output] = None,
     ) -> str:
         if not output:
             output = aiconfig.get_latest_output(prompt)
